package com.censoft.censoftrongtong.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.censoft.censoftrongtong.domain.CurrentRiskUserPatrolDetail;
import com.censoft.censoftrongtong.service.ICurrentRiskUserPatrolDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 现状风险用户巡查明细Controller
 * 
 * @author ruoyi
 * @date 2023-12-05
 */
@RestController
@RequestMapping("/risk/currentRiskPatrolDetail")
public class CurrentRiskUserPatrolDetailController extends BaseController
{
    @Autowired
    private ICurrentRiskUserPatrolDetailService currentRiskUserPatrolDetailService;

    /**
     * 查询现状风险用户巡查明细列表
     */
    @PreAuthorize("@ss.hasPermi('risk:currentRiskPatrolDetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(CurrentRiskUserPatrolDetail currentRiskUserPatrolDetail)
    {
        startPage();
        List<CurrentRiskUserPatrolDetail> list = currentRiskUserPatrolDetailService.selectCurrentRiskUserPatrolDetailList(currentRiskUserPatrolDetail);
        return getDataTable(list);
    }

    /**
     * 导出现状风险用户巡查明细列表
     */
    @PreAuthorize("@ss.hasPermi('risk:currentRiskPatrolDetail:export')")
    @Log(title = "现状风险用户巡查明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CurrentRiskUserPatrolDetail currentRiskUserPatrolDetail)
    {
        List<CurrentRiskUserPatrolDetail> list = currentRiskUserPatrolDetailService.selectCurrentRiskUserPatrolDetailList(currentRiskUserPatrolDetail);
        ExcelUtil<CurrentRiskUserPatrolDetail> util = new ExcelUtil<CurrentRiskUserPatrolDetail>(CurrentRiskUserPatrolDetail.class);
        util.exportExcel(response, list, "现状风险用户巡查明细数据");
    }

    /**
     * 获取现状风险用户巡查明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('risk:currentRiskPatrolDetail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(currentRiskUserPatrolDetailService.selectCurrentRiskUserPatrolDetailById(id));
    }

    /**
     * 新增现状风险用户巡查明细
     */
    @PreAuthorize("@ss.hasPermi('risk:currentRiskPatrolDetail:add')")
    @Log(title = "现状风险用户巡查明细", businessType = BusinessType.INSERT)
    @PostMapping("save")
    public AjaxResult add(@RequestBody CurrentRiskUserPatrolDetail currentRiskUserPatrolDetail)
    {
        return toAjax(currentRiskUserPatrolDetailService.insertCurrentRiskUserPatrolDetail(currentRiskUserPatrolDetail));
    }

    /**
     * 修改现状风险用户巡查明细
     */
    @PreAuthorize("@ss.hasPermi('risk:currentRiskPatrolDetail:edit')")
    @Log(title = "现状风险用户巡查明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CurrentRiskUserPatrolDetail currentRiskUserPatrolDetail)
    {
        return toAjax(currentRiskUserPatrolDetailService.updateCurrentRiskUserPatrolDetail(currentRiskUserPatrolDetail));
    }

    /**
     * 删除现状风险用户巡查明细
     */
    @PreAuthorize("@ss.hasPermi('risk:currentRiskPatrolDetail:remove')")
    @Log(title = "现状风险用户巡查明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(currentRiskUserPatrolDetailService.deleteCurrentRiskUserPatrolDetailByIds(ids));
    }
}
